==> SmugMug-3.5.6.0.zip: SmugMug.lrplugin/SmMetadataProvider.lua <==
LuaQ                    
4      A@   E     \           ܀   AA  E   \       AB
  $  dB                                        $                               require 
       SmAccount        SmAlbum        SmAPI 	       SmFolder 	       SmLogger        SmNode        SmTable        schemaVersion       @       metadataFieldsForPhotos        updateFromEarlierSchemaVersion            !   $        E   @  @     A   \            	       tostring        string        gsub        /(.*)/([^/]+)$        %2                         (   /         @@                updateLegacySettings                         3   E    -    @   @   @@  E   \ @   A 
A  D  \ 	A@   @@ E   \ @  A     AB@    ܀  W C ACW  @ A            setRemoteId        debugf #       Pre-update for Folder settings: %s 	       tostring        setCollectionSetSettings        UrlName $       Post-update for Folder settings: %s 
       getParent        string        gsub 
       /([^/]+)$          	       BASE_URI                         I            AA   E   \ . ܂ B      @  CA@ C     FA\ Z    @WAD KC  @  \C  D FC\  C B E \ C      C     W@  AC @  W WA 
ƃ @  @C@    
E  	EDĀ  DD	 E	 E  	    E	  	W  DA@Dń   ܄ ă	 ń   ܄ ă	K\  B FDC  @   C   B FDC 
KC\     @CA   @   WA   @ B E  \ C   E   AD    C  @ Ca     "          require        SmConstants        ipairs        getRemoteId 
       getParent        getUri        isAlbum         debugf        Pre-update AlbumID: %s 	       tostring        setRemoteId        Post-update AlbumUri: %s 
       categoryUris        subcategoryUris        get        errors        Message        Ok        getUriByLocator        Folder 	       stripUri        getCollectionInfoSummary "       Pre-update for Album settings: %s        name        setCollectionSettings        collectionSettings #       Post-update for Album settings: %s        getChildren 	       tonumber       ?       Pre-update FolderUri: %s        Post-update FolderUri: %s                                      @A  @     ŀ   ܀ @   A A  A  AB    ܁  CAAC  CE  \ B 
  K\ @    	  	  CBD @ C  E B CCF  W@AGƃCCGƃCGƃCGƃCH   HƃCCH   CHƃC H܃          CBD	 @ C   @ C  CB	 @ C a   D  K	 \A  (          debug :       SmMetadataProvider.updateFromEarlierSchemaVersion - start        require        SmAuth 	       SmPlugin        ?       assertHasPrivateWriteAccess 2       SmMetadataProvider.updateFromEarlierSchemaVersion        debugf        Schema Update from %s to %d 	       tostring        schemaVersion        getPublishServices        _PLUGIN        id        ipairs        getName        getPublishSettings 
       categoryUris        subcategoryUris        Service: %s 	       indirect        sync        tokenStatus        TOKEN_REVOKED        uid        prefs        AlbumTemplates        AlbumTemplateSettings        Communities        Themes        Printmarks        Watermarks        join        getChildCollectionSets        getChildCollections $       Pre-Hierarchy Migration for '%s'... #       Post-Hierarchy Migration for '%s'. 8       SmMetadataProvider.updateFromEarlierSchemaVersion - end                             

==> SmugMug-3.5.9.1.zip: SmugMug.lrplugin/SmMetadataProvider.lua <==
LuaQ                    
4      A@   E     \           ܀   AA  E   \       AB
  $  dB                                        $                               require 
       SmAccount        SmAlbum        SmAPI 	       SmFolder 	       SmLogger        SmNode        SmTable        schemaVersion       @       metadataFieldsForPhotos        updateFromEarlierSchemaVersion            !   $        E   @  @     A   \            	       tostring        string        gsub        /(.*)/([^/]+)$        %2                         (   /         @@                updateLegacySettings                         3   E    -    @   @   @@  E   \ @   A 
A  D  \ 	A@   @@ E   \ @  A     AB@    ܀  W C ACW  @ A            setRemoteId        tracef #       Pre-update for Folder settings: %s 	       tostring        setCollectionSetSettings        UrlName $       Post-update for Folder settings: %s 
       getParent        string        gsub 
       /([^/]+)$          	       BASE_URI                         I            AA   E   \ . ܂ B      @  CA@ C     FA\ Z    @WAD KC  @  \C  D FC\  C B E \ C      C     W@  AC @  W WA 
ƃ @  @C@    
E  	EDĀ  DD	 E	 E  	    E	  	W  DA@Dń   ܄ ă	 ń   ܄ ă	K\  B FDC  @   C   B FDC 
KC\     @CA   @   WA   @ B E  \ C   E   AD    C  @ Ca     "          require        SmConstants        ipairs        getRemoteId 
       getParent        getUri        isAlbum         tracef        Pre-update AlbumID: %s 	       tostring        setRemoteId        Post-update AlbumUri: %s 
       categoryUris        subcategoryUris        get        errors        Message        Ok        getUriByLocator        Folder 	       stripUri        getCollectionInfoSummary "       Pre-update for Album settings: %s        name        setCollectionSettings        collectionSettings #       Post-update for Album settings: %s        getChildren 	       tonumber       ?       Pre-update FolderUri: %s        Post-update FolderUri: %s                                      @A  @     ŀ   ܀ @   A A  A  AB    ܁  CAAC  CE  \ B 
  K\ @    	  	  CBD @ C  E B CCF  W@AGƃCCGƃCGƃCGƃCH   HƃCCH   CHƃC H܃          CBD	 @ C   @ C  CB	 @ C a   D  K	 \A  (          trace :       SmMetadataProvider.updateFromEarlierSchemaVersion - start        require        SmAuth 	       SmPlugin        ?       assertHasPrivateWriteAccess 2       SmMetadataProvider.updateFromEarlierSchemaVersion        tracef        Schema Update from %s to %d 	       tostring        schemaVersion        getPublishServices        _PLUGIN        id        ipairs        getName        getPublishSettings 
       categoryUris        subcategoryUris        Service: %s 	       indirect        sync        tokenStatus        TOKEN_REVOKED        uid        prefs        AlbumTemplates        AlbumTemplateSettings        Communities        Themes        Printmarks        Watermarks        join        getChildCollectionSets        getChildCollections $       Pre-Hierarchy Migration for '%s'... #       Post-Hierarchy Migration for '%s'. 8       SmMetadataProvider.updateFromEarlierSchemaVersion - end                             
